# {py:mod}`ngff_zarr.ngff_image_to_itk_image`

```{py:module} ngff_zarr.ngff_image_to_itk_image
```

```{autodoc2-docstring} ngff_zarr.ngff_image_to_itk_image
:allowtitles:
```

## Module Contents

### Functions

````{list-table}
:class: autosummary longtable
:align: left

* - {py:obj}`_dtype_to_component_type <ngff_zarr.ngff_image_to_itk_image._dtype_to_component_type>`
  - ```{autodoc2-docstring} ngff_zarr.ngff_image_to_itk_image._dtype_to_component_type
    :summary:
    ```
* - {py:obj}`ngff_image_to_itk_image <ngff_zarr.ngff_image_to_itk_image.ngff_image_to_itk_image>`
  - ```{autodoc2-docstring} ngff_zarr.ngff_image_to_itk_image.ngff_image_to_itk_image
    :summary:
    ```
````

### API

````{py:function} _dtype_to_component_type(dtype)
:canonical: ngff_zarr.ngff_image_to_itk_image._dtype_to_component_type

```{autodoc2-docstring} ngff_zarr.ngff_image_to_itk_image._dtype_to_component_type
```
````

````{py:function} ngff_image_to_itk_image(ngff_image: ngff_zarr.ngff_image.NgffImage, wasm: bool = True)
:canonical: ngff_zarr.ngff_image_to_itk_image.ngff_image_to_itk_image

```{autodoc2-docstring} ngff_zarr.ngff_image_to_itk_image.ngff_image_to_itk_image
```
````
